/**
 * Associa um parceiro de negocios a um numero ou codigo de integracao com outro sistema qualquer.
 *
 * Observao:
 * - Se o numero ou codigo de integracao ainda nao existir, e criado um novo parceiro para ser
 *   associado ao mesmo.
 *
 * @author Ederson Melquiades da Cunha <ederson@teknisa.com>
 *
 * @param P_NRORG IN Organizacao logada
 * @param P_CDOPERADOR IN Operador logado
 *
 * @param P_CDINTEGRAPARC IN Numero de integracao do parceiro de negocios (ex: credencial do participante de um evento)
 * @param P_CDSISTEMAINTEGRAPARC IN Sistema da integracao (ex: 'PESQUISA_TOTEM')
 *
 * Os parametros abaixo se referem ao parceiro de negocios que sera gerado caso o numero de integracao ainda nao exista
 *
 * @param P_CDTIPOPARCEIRO IN Tipo de parceiro (referencia com a tabela TIPOPARCEIRO, ex: 'PESSOA')
 * @param P_CDTIPOINSCRICAO IN Tipo de inscricao (referencia com a tabela TIPOINSCRICAO, ex.: 'LIVRE')
 * @param P_NMPRINCIPALPARC IN Nome principal do parceiro de negocios
 * @param P_NMSECUNDARIPARC IN Nome secundario do parceiro de negocios
 * @param P_IDPESSOAFISICA IN Identificador de parceiro pessoa fisica ('S' ou 'N')
 * @param P_IDINSTITUICAO IN Identificador de parceiro instituico ('S' ou 'N')
 *
 * @param P_NRPARCNEGOCIO OUT Retorna o numero do parceiro de negocios associado ao CDINTEGRAPARC
 *
 */

CREATE OR REPLACE
PROCEDURE GERA_PARCNEGOCIO_INTEGRAPARC (
   P_NRORG IN ORGANIZACAO.NRORG%TYPE,
   P_CDOPERADOR IN OPERADOR.CDOPERADOR%TYPE,
   P_CDINTEGRAPARC IN INTEGRAPARC.CDINTEGRAPARC%TYPE,
   P_CDSISTEMAINTEGRAPARC IN INTEGRAPARC.CDSISTEMAINTEGRAPARC%TYPE,
   P_CDTIPOPARCEIRO IN TIPOPARCEIRO.CDTIPOPARCEIRO%TYPE,
   P_CDTIPOINSCRICAO IN PARCNEGOCIO.CDTIPOINSCRICAO%TYPE,
   P_NMPRINCIPALPARC IN PARCNEGOCIO.NMPRINCIPALPARC%TYPE,
   P_NMSECUNDARIPARC IN PARCNEGOCIO.NMSECUNDARIPARC%TYPE,
   P_IDPESSOAFISICA IN PARCNEGOCIO.IDPESSOAFISICA%TYPE,
   P_IDINSTITUICAO IN PARCNEGOCIO.IDPESSOAFISICA%TYPE,
   P_NRPARCNEGOCIO OUT PARCNEGOCIO.NRPARCNEGOCIO%TYPE
) IS
   V_NRPARCNEGOCIO NOVOCODIGO.NRSEQUENCIAL%TYPE;
   V_NRPARCERIA NOVOCODIGO.NRSEQUENCIAL%TYPE;
   V_NRINTEGRAPARC NOVOCODIGO.NRSEQUENCIAL%TYPE;
BEGIN
   SELECT NVL(MAX(NRPARCNEGOCIO), 0)
     INTO P_NRPARCNEGOCIO
     FROM INTEGRAPARC
    WHERE NRORG = P_NRORG
      AND CDINTEGRAPARC = P_CDINTEGRAPARC
      AND CDSISTEMAINTEGRAPARC = P_CDSISTEMAINTEGRAPARC;
   IF P_NRPARCNEGOCIO = 0 THEN
      -- #######################################################################
      -- ############################# PARCNEGOCIO #############################
      -- #######################################################################
      NOVO_CODIGO('PARCNEGOCIO', V_NRPARCNEGOCIO, 1, P_NRORG);
      P_NRPARCNEGOCIO := V_NRPARCNEGOCIO;
      INSERT INTO PARCNEGOCIO
         (NRPARCNEGOCIO, CDTIPOPARCPRINCIPAL, CDTIPOINSCRICAO,
          NMPRINCIPALPARC, NMSECUNDARIPARC, DTNASCIFUNDPARC,
          NRINSCRICAOPARC, IDPESSOAFISICA, IDINSTITUICAO,
          NRORG, IDATIVO, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU)
      VALUES
         (P_NRPARCNEGOCIO, P_CDTIPOPARCEIRO, P_CDTIPOINSCRICAO,
          P_NMPRINCIPALPARC, P_NMSECUNDARIPARC, SYSDATE,
          SUBSTR(P_CDINTEGRAPARC, 1, 20), P_IDPESSOAFISICA, P_IDINSTITUICAO,
          P_NRORG, 'S', SYSDATE, SYSDATE, P_NRORG, P_CDOPERADOR, P_NRORG, P_CDOPERADOR);
      -- #######################################################################
      -- ############################## PARCERIA ###############################
      -- #######################################################################
      NOVO_CODIGO('PARCERIA', V_NRPARCERIA, 1, P_NRORG);
      INSERT INTO PARCERIA
         (NRPARCERIA, NRPARCNEGOCIO, CDTIPOPARCEIRO,
          NRORG, IDATIVO, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU)
      VALUES
         (V_NRPARCERIA, P_NRPARCNEGOCIO, P_CDTIPOPARCEIRO,
          P_NRORG, 'S', SYSDATE, SYSDATE, P_NRORG, P_CDOPERADOR, P_NRORG, P_CDOPERADOR);
      -- #######################################################################
      -- ############################# INTEGRAPARC #############################
      -- #######################################################################
      NOVO_CODIGO('INTEGRAPARC', V_NRINTEGRAPARC, 1, P_NRORG);
      INSERT INTO INTEGRAPARC
         (NRINTEGRAPARC, NRPARCNEGOCIO, CDSISTEMAINTEGRAPARC, CDINTEGRAPARC,
          NRORG, IDATIVO, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU)
      VALUES
         (V_NRINTEGRAPARC, P_NRPARCNEGOCIO, P_CDSISTEMAINTEGRAPARC, P_CDINTEGRAPARC,
          P_NRORG, 'S', SYSDATE, SYSDATE, P_NRORG, P_CDOPERADOR, P_NRORG, P_CDOPERADOR);
      COMMIT;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('GERA_PARCNEGOCIO_INTEGRAPARC','5.55.010'); END;
/